"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EmbeddedComponentRN = void 0;
var _javascriptSdk = require("@notabene/javascript-sdk");
var _notabeneSdk = require("./notabene-sdk.js");
function isTransactionResponse(response) {
  return response.type === _javascriptSdk.CMType.COMPLETE;
}
class EmbeddedComponentRN extends _javascriptSdk.EmbeddedComponent {
  constructor(url, deepLink, value) {
    super(url, value);
    this.deepLink = deepLink;
  }
  async openModal() {
    try {
      const response = await openComponent(this.url, this.deepLink);

      // Parse the response to check for conclusive errors from the JS SDK
      const [_, fragment] = response.split('#');
      const params = new URLSearchParams(fragment);
      const encodedMessage = params.has('message') ? params.get('message') : undefined;
      const parsedResponse = {
        ...(encodedMessage ? JSON.parse(encodedMessage) : {})
      };
      if (parsedResponse?.type === _javascriptSdk.CMType.ERROR) {
        return Promise.reject({
          ...parsedResponse,
          deepLink: response
        });
      }
      if (parsedResponse?.type === _javascriptSdk.CMType.CANCEL) {
        return Promise.reject({
          ...parsedResponse,
          deepLink: response
        });
      }

      // If response is of type COMPLETE, TypeScript will infer the correct type here
      if (isTransactionResponse(parsedResponse)) {
        const finalResponse = {
          value: this.value,
          ivms101: parsedResponse.ivms101,
          proof: parsedResponse.proof,
          txCreate: parsedResponse.txCreate,
          txUpdate: parsedResponse.txUpdate,
          requestID: parsedResponse.requestID,
          valid: parsedResponse.valid,
          status: parsedResponse.status,
          errors: parsedResponse.errors,
          deepLink: response
        };
        return finalResponse;
      }
      return Promise.reject({
        ...parsedResponse,
        deepLink: response
      });
    } catch (ex) {
      const error = ex;
      if (error.message?.includes('The operation couldn’t be completed')) {
        return Promise.reject('User cancellation');
      }
      return Promise.reject(error);
    }
  }
}
exports.EmbeddedComponentRN = EmbeddedComponentRN;
async function openComponent(url, deepLink) {
  return await _notabeneSdk.NotabeneSdk.open(url, deepLink);
}
//# sourceMappingURL=embedded-component.js.map