import 'react-native-url-polyfill/auto';
import Notabene, {
  type CallbackOptions,
  type NotabeneConfig,
} from '@notabene/javascript-sdk';
import { EmbeddedComponentRN } from './embedded-component';

export interface NotabeneRNConfig extends NotabeneConfig {
  componentDeepLink?: string; // The deep link to the component within the app
  resultDeepLink: string; // The deep link to receive the result within the app
}

export default class NotabeneRN extends Notabene {
  componentDeepLink?: string;
  resultDeepLink: string;

  constructor(config: NotabeneRNConfig) {
    if (!config.uxUrl?.length) {
      throw new Error('Notabene `uxUrl` is required');
    }
    if (!config.nodeUrl?.length) {
      throw new Error('Notabene `nodeUrl` is required');
    }
    if (!config.authToken?.length) {
      throw new Error('Notabene `authToken` is required');
    }
    if (!config.resultDeepLink?.length) {
      throw new Error('Notabene `resultDeepLink` is required');
    }

    super(config);

    this.resultDeepLink = config.resultDeepLink;
    this.componentDeepLink = config.componentDeepLink;
  }

  /**
   * Creates a new embedded component
   *
   * @param path - The path of the component
   * @param value - Transaction data
   * @param options - Optional transaction options
   * @param callbacks - Optional callback configuration
   * @returns A new EmbeddedComponent instance
   * @internal
   */
  createComponent<V, O>(
    path: string,
    value: Partial<V>,
    options?: O,
    callbacks?: CallbackOptions
  ) {
    return new EmbeddedComponentRN<V, O>(
      this.componentUrl(path, value, options, callbacks),
      this.resultDeepLink,
      value
    );
  }

  /**
   * Generates a URL for a Notabene component
   *
   * @param path - The path of the component
   * @param value - Transaction data
   * @param configuration - Optional transaction configuration
   * @param callbacks - Optional callback configuration
   * @returns component URL
   * @internal
   */
  componentUrl<V, O>(
    path: string,
    value: V,
    configuration?: O,
    callbacks?: CallbackOptions
  ): string {
    const url = super.componentUrl(path, value, configuration, callbacks);
    const sdkUrl = new URL(url);
    sdkUrl.searchParams.set('redirect_uri', this.resultDeepLink);
    return sdkUrl.toString();
  }
}
